<?php
/**
 * Customizer default options
 *
 * @package Theme Palace
 * @subpackage Magazinews Pro
 * @since Magazinews Pro 1.0.0
 * @return array An array of default values
 */

function magazinews_pro_get_default_theme_options() {
	$theme_data = wp_get_theme();
	$magazinews_pro_default_options = array(
		// Color Options
		'header_title_color'			=> '#fff',
		'header_tagline_color'			=> '#fff',
		'header_txt_logo_extra'			=> 'show-all',
		'colorscheme_hue'				=> '#ff4443',
		'colorscheme'					=> 'default',
		'theme_color'					=> 'dark-version',
		
		// typography Options
		'theme_typography' 				=> 'default',
		'body_theme_typography' 		=> 'default',
		
		// loader
		'loader_enable'         		=> false,
		'loader_icon'         			=> 'default',

		// breadcrumb
		'breadcrumb_enable'				=> true,
		'breadcrumb_separator'			=> '/',
		
		// layout 
		'site_layout'         			=> 'frame-layout',
		'sidebar_position'         		=> 'right-sidebar',
		'post_sidebar_position' 		=> 'right-sidebar',
		'page_sidebar_position' 		=> 'right-sidebar',
		'menu_sticky'					=> true,
		'nav_search_enable'				=> true,

		// excerpt options
		'long_excerpt_length'           => 25,
		'read_more_text'           		=> esc_html__( 'Read More', 'magazinews-pro' ),
		
		// pagination options
		'pagination_enable'         	=> true,
		'pagination_type'         		=> 'default',

		// footer options
		'copyright_text'           		=> sprintf( esc_html_x( 'Copyright &copy; %1$s %2$s. ', '1: Year, 2: Site Title with home URL', 'magazinews-pro' ), '[the-year]', '[site-link]' ) . esc_html__( 'All Rights Reserved | ', 'magazinews-pro' ) . esc_html( $theme_data->get( 'Name') ) . '&nbsp;' . esc_html__( 'by', 'magazinews-pro' ). '&nbsp;<a target="_blank" href="'. esc_url( $theme_data->get( 'AuthorURI' ) ) .'">'. esc_html( ucwords( $theme_data->get( 'Author' ) ) ) .'</a>',
		'scroll_top_visible'        	=> true,

		// reset options
		'reset_options'      			=> false,
		
		// homepage options
		'enable_frontpage_content' 		=> false,

		// homepage sections sortable
		'sortable' 						=> 'headline,slider,featured,editor_choice,popular,trending,featured_story,author_collection,gallery,blog',

		// blog/archive options
		'your_latest_posts_title' 		=> esc_html__( 'Blogs', 'magazinews-pro' ),
		'hide_category'					=> false,
		'hide_author'					=> false,
		'hide_date'					=> false,

		// single post theme options
		'single_post_hide_date' 		=> false,
		'single_post_hide_author'		=> false,
		'single_post_hide_category'		=> false,
		'single_post_hide_tags'			=> false,

		/* Front Page */

		// Topbar
		'topbar_section_enable'			=> false,
		'secondary_menu_enable'			=> false,
		'social_menu_enable'			=> false,

		// Headline
		'headline_section_enable'		=> true,
		'headline_content_type'			=> 'category',
		'headline_count'				=> 3,
		'headline_title'				=> esc_html__( 'Breaking News', 'magazinews-pro' ),

		// Slider
		'slider_section_enable'			=> true,
		'slider_auto_play'				=> false,
		'slider_content_type'			=> 'category',
		'slider_count'					=> 4,

		// Featured
		'featured_section_enable'		=> true,
		'featured_title'				=> esc_html__( 'Today&#39;s Featured', 'magazinews-pro' ),

		// Editor Choice
		'editor_choice_section_enable'	=> true,
		'editor_choice_title'			=> esc_html__( 'Editor&#39;s Choice', 'magazinews-pro' ),
		'editor_choice_readmore'		=> esc_html__( 'Read More', 'magazinews-pro' ),

		// Popular
		'popular_section_enable'		=> true,
		'popular_title'					=> esc_html__( 'Most Popular', 'magazinews-pro' ),

		// Trending
		'trending_section_enable'		=> true,
		'trending_title'				=> esc_html__( 'Trending News', 'magazinews-pro' ),

		// Featured Story
		'featured_story_section_enable' => true,
		'featured_story_content_type'	=> 'category',
		'featured_story_count'			=> 4,
		'featured_story_readmore'		=> esc_html__( 'Read More', 'magazinews-pro' ),

		// Author Collection
		'author_collection_section_enable' 	=> true,
		'author_collection_auto_play' 	=> true,
		'author_collection_title'		=> esc_html__( 'Author Collection', 'magazinews-pro' ),
		'author_collection_btn_title'	=> esc_html__( 'Show All Collection', 'magazinews-pro' ),
		'author_collection_content_type' 	=> 'category',
		'author_collection_count'		=> 5,

		// Gallery
		'gallery_section_enable'		=> true,
		'gallery_title'					=> esc_html__( 'Gallery Posts', 'magazinews-pro' ),

		// blog
		'blog_section_enable'			=> true,
		'blog_content_type'				=> 'recent',
		'blog_count'					=> 3,
		'blog_readmore_title'			=> esc_html__( 'Read More', 'magazinews-pro' ),
		'blog_title'					=> esc_html__( 'Recently Viewed', 'magazinews-pro' ),
		'blog_btn_title'				=> esc_html__( 'Show All', 'magazinews-pro' ),

	);

	$output = apply_filters( 'magazinews_pro_default_theme_options', $magazinews_pro_default_options );

	// Sort array in ascending order, according to the key:
	if ( ! empty( $output ) ) {
		ksort( $output );
	}

	return $output;
}