<?php
/**
 * Author Collection Section options
 *
 * @package Theme Palace
 * @subpackage Magazinews Pro
 * @since Magazinews Pro 1.0.0
 */

// Add Author Collection section
$wp_customize->add_section( 'magazinews_pro_author_collection_section', array(
	'title'             => esc_html__( 'Author Collection Slider','magazinews-pro' ),
	'description'       => esc_html__( 'Author Collection Section options.', 'magazinews-pro' ),
	'panel'             => 'magazinews_pro_front_page_panel',
) );

// Author Collection content enable control and setting
$wp_customize->add_setting( 'magazinews_pro_theme_options[author_collection_section_enable]', array(
	'default'			=> 	$options['author_collection_section_enable'],
	'sanitize_callback' => 'magazinews_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Magazinews_Pro_Switch_Control( $wp_customize, 'magazinews_pro_theme_options[author_collection_section_enable]', array(
	'label'             => esc_html__( 'Author Collection Section Enable', 'magazinews-pro' ),
	'section'           => 'magazinews_pro_author_collection_section',
	'on_off_label' 		=> magazinews_pro_switch_options(),
) ) );

// Author Collection auto play enable control and setting
$wp_customize->add_setting( 'magazinews_pro_theme_options[author_collection_auto_play]', array(
	'default'			=> 	$options['author_collection_auto_play'],
	'sanitize_callback' => 'magazinews_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Magazinews_Pro_Switch_Control( $wp_customize, 'magazinews_pro_theme_options[author_collection_auto_play]', array(
	'label'             => esc_html__( 'Auto Play Enable', 'magazinews-pro' ),
	'section'           => 'magazinews_pro_author_collection_section',
	'on_off_label' 		=> magazinews_pro_switch_options(),
	'active_callback' 	=> 'magazinews_pro_is_author_collection_section_enable',
) ) );

// author_collection title setting and control
$wp_customize->add_setting( 'magazinews_pro_theme_options[author_collection_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['author_collection_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'magazinews_pro_theme_options[author_collection_title]', array(
	'label'           	=> esc_html__( 'Title', 'magazinews-pro' ),
	'section'        	=> 'magazinews_pro_author_collection_section',
	'active_callback' 	=> 'magazinews_pro_is_author_collection_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'magazinews_pro_theme_options[author_collection_title]', array(
		'selector'            => '#featured-collection .section-header-wrapper .section-header h2.section-title',
		'settings'            => 'magazinews_pro_theme_options[author_collection_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'magazinews_pro_author_collection_title_partial',
    ) );
}

// author_collection title setting and control
$wp_customize->add_setting( 'magazinews_pro_theme_options[author_collection_btn_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['author_collection_btn_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'magazinews_pro_theme_options[author_collection_btn_title]', array(
	'label'           	=> esc_html__( 'Button Label', 'magazinews-pro' ),
	'section'        	=> 'magazinews_pro_author_collection_section',
	'active_callback' 	=> 'magazinews_pro_is_author_collection_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'magazinews_pro_theme_options[author_collection_btn_title]', array(
		'selector'            => '#featured-collection .view-all a.more-link',
		'settings'            => 'magazinews_pro_theme_options[author_collection_btn_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'magazinews_pro_author_collection_btn_title_partial',
    ) );
}

// author_collection url setting and control
$wp_customize->add_setting( 'magazinews_pro_theme_options[author_collection_btn_url]', array(
	'sanitize_callback' => 'esc_url_raw',
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'magazinews_pro_theme_options[author_collection_btn_url]', array(
	'label'           	=> esc_html__( 'Button Url', 'magazinews-pro' ),
	'section'        	=> 'magazinews_pro_author_collection_section',
	'active_callback' 	=> 'magazinews_pro_is_author_collection_section_enable',
	'type'				=> 'url',
) );

// Event social icons number control and setting
$wp_customize->add_setting( 'magazinews_pro_theme_options[author_collection_count]', array(
	'default'          	=> $options['author_collection_count'],
	'sanitize_callback' => 'magazinews_pro_sanitize_number_range',
	'validate_callback' => 'magazinews_pro_validate_author_collection_count',
) );

$wp_customize->add_control( 'magazinews_pro_theme_options[author_collection_count]', array(
	'label'             => esc_html__( 'Number of Slides', 'magazinews-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 10. Please input the valid number and save. Then refresh the page to see the change.', 'magazinews-pro' ),
	'section'           => 'magazinews_pro_author_collection_section',
	'active_callback'   => 'magazinews_pro_is_author_collection_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 10,
		'style' => 'width: 100px;'
		),
) );

// Author Collection content type control and setting
$wp_customize->add_setting( 'magazinews_pro_theme_options[author_collection_content_type]', array(
	'default'          	=> $options['author_collection_content_type'],
	'sanitize_callback' => 'magazinews_pro_sanitize_select',
) );

$wp_customize->add_control( 'magazinews_pro_theme_options[author_collection_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'magazinews-pro' ),
	'section'           => 'magazinews_pro_author_collection_section',
	'type'				=> 'select',
	'active_callback' 	=> 'magazinews_pro_is_author_collection_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'magazinews-pro' ),
		'post' 		=> esc_html__( 'Post', 'magazinews-pro' ),
		'category' 	=> esc_html__( 'Category', 'magazinews-pro' ),
	),
) );

for ( $i = 1; $i <= $options['author_collection_count']; $i++ ) :
	// author collection pages drop down chooser control and setting
	$wp_customize->add_setting( 'magazinews_pro_theme_options[author_collection_content_page_' . $i . ']', array(
		'sanitize_callback' => 'magazinews_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Magazinews_Pro_Dropdown_Chooser( $wp_customize, 'magazinews_pro_theme_options[author_collection_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'magazinews-pro' ), $i ),
		'section'           => 'magazinews_pro_author_collection_section',
		'choices'			=> magazinews_pro_page_choices(),
		'active_callback'	=> 'magazinews_pro_is_author_collection_section_content_page_enable',
	) ) );

	// author collection posts drop down chooser control and setting
	$wp_customize->add_setting( 'magazinews_pro_theme_options[author_collection_content_post_' . $i . ']', array(
		'sanitize_callback' => 'magazinews_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Magazinews_Pro_Dropdown_Chooser( $wp_customize, 'magazinews_pro_theme_options[author_collection_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'magazinews-pro' ), $i ),
		'section'           => 'magazinews_pro_author_collection_section',
		'choices'			=> magazinews_pro_post_choices(),
		'active_callback'	=> 'magazinews_pro_is_author_collection_section_content_post_enable',
	) ) );
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'magazinews_pro_theme_options[author_collection_content_category]', array(
	'sanitize_callback' => 'magazinews_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Magazinews_Pro_Dropdown_Taxonomies_Control( $wp_customize,'magazinews_pro_theme_options[author_collection_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'magazinews-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'magazinews-pro' ),
	'section'           => 'magazinews_pro_author_collection_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'magazinews_pro_is_author_collection_section_content_category_enable'
) ) );
