<?php
/**
 * Slider Section options
 *
 * @package Theme Palace
 * @subpackage Magazinews Pro
 * @since Magazinews Pro 1.0.0
 */

// Add Slider section
$wp_customize->add_section( 'magazinews_pro_slider_section', array(
	'title'             => esc_html__( 'Main Slider','magazinews-pro' ),
	'description'       => esc_html__( 'Slider Section options.', 'magazinews-pro' ),
	'panel'             => 'magazinews_pro_front_page_panel',
) );

// Slider content enable control and setting
$wp_customize->add_setting( 'magazinews_pro_theme_options[slider_section_enable]', array(
	'default'			=> 	$options['slider_section_enable'],
	'sanitize_callback' => 'magazinews_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Magazinews_Pro_Switch_Control( $wp_customize, 'magazinews_pro_theme_options[slider_section_enable]', array(
	'label'             => esc_html__( 'Slider Section Enable', 'magazinews-pro' ),
	'section'           => 'magazinews_pro_slider_section',
	'on_off_label' 		=> magazinews_pro_switch_options(),
) ) );

// Slider auto play enable control and setting
$wp_customize->add_setting( 'magazinews_pro_theme_options[slider_auto_play]', array(
	'default'			=> 	$options['slider_auto_play'],
	'sanitize_callback' => 'magazinews_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Magazinews_Pro_Switch_Control( $wp_customize, 'magazinews_pro_theme_options[slider_auto_play]', array(
	'label'             => esc_html__( 'Auto Play Enable', 'magazinews-pro' ),
	'section'           => 'magazinews_pro_slider_section',
	'on_off_label' 		=> magazinews_pro_switch_options(),
	'active_callback'   => 'magazinews_pro_is_slider_section_enable',
) ) );

// Event social icons number control and setting
$wp_customize->add_setting( 'magazinews_pro_theme_options[slider_count]', array(
	'default'          	=> $options['slider_count'],
	'sanitize_callback' => 'magazinews_pro_sanitize_number_range',
	'validate_callback' => 'magazinews_pro_validate_slider_count',
) );

$wp_customize->add_control( 'magazinews_pro_theme_options[slider_count]', array(
	'label'             => esc_html__( 'Number of Slides', 'magazinews-pro' ),
	'description'       => esc_html__( 'Note: Min 3 & Max 10. Please input the valid number and save. Then refresh the page to see the change.', 'magazinews-pro' ),
	'section'           => 'magazinews_pro_slider_section',
	'active_callback'   => 'magazinews_pro_is_slider_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 3,
		'max'	=> 10,
		'style' => 'width: 100px;'
		),
) );

// Slider content type control and setting
$wp_customize->add_setting( 'magazinews_pro_theme_options[slider_content_type]', array(
	'default'          	=> $options['slider_content_type'],
	'sanitize_callback' => 'magazinews_pro_sanitize_select',
) );

$wp_customize->add_control( 'magazinews_pro_theme_options[slider_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'magazinews-pro' ),
	'section'           => 'magazinews_pro_slider_section',
	'type'				=> 'select',
	'active_callback' 	=> 'magazinews_pro_is_slider_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'magazinews-pro' ),
		'post' 		=> esc_html__( 'Post', 'magazinews-pro' ),
		'category' 	=> esc_html__( 'Category', 'magazinews-pro' ),
	),
) );

for ( $i = 1; $i <= $options['slider_count']; $i++ ) :
	// slider pages drop down chooser control and setting
	$wp_customize->add_setting( 'magazinews_pro_theme_options[slider_content_page_' . $i . ']', array(
		'sanitize_callback' => 'magazinews_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Magazinews_Pro_Dropdown_Chooser( $wp_customize, 'magazinews_pro_theme_options[slider_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'magazinews-pro' ), $i ),
		'section'           => 'magazinews_pro_slider_section',
		'choices'			=> magazinews_pro_page_choices(),
		'active_callback'	=> 'magazinews_pro_is_slider_section_content_page_enable',
	) ) );

	// slider posts drop down chooser control and setting
	$wp_customize->add_setting( 'magazinews_pro_theme_options[slider_content_post_' . $i . ']', array(
		'sanitize_callback' => 'magazinews_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Magazinews_Pro_Dropdown_Chooser( $wp_customize, 'magazinews_pro_theme_options[slider_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'magazinews-pro' ), $i ),
		'section'           => 'magazinews_pro_slider_section',
		'choices'			=> magazinews_pro_post_choices(),
		'active_callback'	=> 'magazinews_pro_is_slider_section_content_post_enable',
	) ) );
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'magazinews_pro_theme_options[slider_content_category]', array(
	'sanitize_callback' => 'magazinews_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Magazinews_Pro_Dropdown_Taxonomies_Control( $wp_customize,'magazinews_pro_theme_options[slider_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'magazinews-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'magazinews-pro' ),
	'section'           => 'magazinews_pro_slider_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'magazinews_pro_is_slider_section_content_category_enable'
) ) );
