<?php
/**
 * Author Collection section
 *
 * This is the template for the content of author_collection section
 *
 * @package Theme Palace
 * @subpackage Magazinews Pro
 * @since Magazinews Pro 1.0.0
 */
if ( ! function_exists( 'magazinews_pro_add_author_collection_section' ) ) :
    /**
    * Add author_collection section
    *
    *@since Magazinews Pro 1.0.0
    */
    function magazinews_pro_add_author_collection_section() {
    	$options = magazinews_pro_get_theme_options();
        // Check if author_collection is enabled on frontpage
        $author_collection_enable = apply_filters( 'magazinews_pro_section_status', true, 'author_collection_section_enable' );

        if ( true !== $author_collection_enable ) {
            return false;
        }
        // Get author_collection section details
        $section_details = array();
        $section_details = apply_filters( 'magazinews_pro_filter_author_collection_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render author_collection section now.
        magazinews_pro_render_author_collection_section( $section_details );
    }
endif;

if ( ! function_exists( 'magazinews_pro_get_author_collection_section_details' ) ) :
    /**
    * author_collection section details.
    *
    * @since Magazinews Pro 1.0.0
    * @param array $input author_collection section details.
    */
    function magazinews_pro_get_author_collection_section_details( $input ) {
        $options = magazinews_pro_get_theme_options();

        // Content type.
        $author_collection_content_type  = $options['author_collection_content_type'];
        $author_collection_count = ! empty( $options['author_collection_count'] ) ? $options['author_collection_count'] : 3;
        
        $content = array();
        switch ( $author_collection_content_type ) {
        	
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $author_collection_count; $i++ ) {
                    if ( ! empty( $options['author_collection_content_page_' . $i] ) )
                        $page_ids[] = $options['author_collection_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $author_collection_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $author_collection_count; $i++ ) {
                    if ( ! empty( $options['author_collection_content_post_' . $i] ) )
                        $post_ids[] = $options['author_collection_content_post_' . $i];
                }
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $author_collection_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['author_collection_content_category'] ) ? $options['author_collection_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $author_collection_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }


            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['id']        = get_the_id();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['excerpt']   = magazinews_pro_trim_content( 25 );
                    $page_post['author']    = get_the_author();
                    $page_post['author_url']     = get_author_posts_url( get_the_author_meta( 'ID' ) );
                    $page_post['author_image']   = get_avatar( get_the_author_meta( 'ID' ), 72 );
                    $page_post['author_count']   = count_user_posts( get_the_author_meta( 'ID' ) );
                    $page_post['image']  	= has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// author_collection section content details.
add_filter( 'magazinews_pro_filter_author_collection_section_details', 'magazinews_pro_get_author_collection_section_details' );


if ( ! function_exists( 'magazinews_pro_render_author_collection_section' ) ) :
  /**
   * Start author_collection section
   *
   * @return string author_collection content
   * @since Magazinews Pro 1.0.0
   *
   */
   function magazinews_pro_render_author_collection_section( $content_details = array() ) {
        $options = magazinews_pro_get_theme_options();
        $author_collection_content_type  = $options['author_collection_content_type'];
        $readmore = ! empty( $options['author_collection_readmore'] ) ? $options['author_collection_readmore'] : esc_html__( 'Read More', 'magazinews-pro' );

        if ( empty( $content_details ) ) {
            return;
        } ?>

        <div id="featured-collection" class="relative page-section">
            <div class="wrapper">
                <div class="section-header-wrapper">
                    <?php if ( ! empty( $options['author_collection_title'] ) ) : ?>
                        <div class="section-header">
                            <h2 class="section-title"><?php echo esc_html( $options['author_collection_title'] ); ?></h2>
                        </div><!-- .section-header -->
                    <?php endif; 

                    if ( ! empty( $options['author_collection_btn_title'] ) && ! empty( $options['author_collection_btn_url'] ) ) : ?>
                        <div class="view-all">
                            <a href="<?php echo esc_url( $options['author_collection_btn_url'] ); ?>" class="more-link">
                                <?php 
                                    echo magazinews_pro_get_svg( array( 'icon' => 'angle-right' ) );
                                    echo esc_html( $options['author_collection_btn_title'] ); 
                                ?>
                            </a>
                        </div><!-- .view-all -->
                    <?php endif; ?>
                </div><!-- .section-header-wrapper -->

                <div class="section-content-wrapper" data-slick='{"slidesToShow": 4, "slidesToScroll": 1, "infinite": true, "speed": 1500, "dots": true, "arrows":true, "autoplay": <?php echo $options['author_collection_auto_play'] ? 'true' : 'false'; ?>, "draggable": true, "fade": false }'>
                    <?php foreach ( $content_details as $content ) : ?>
                        <article>
                            <div class="featured-collection-item">
                                <div class="featured-image" style="background-image:url('<?php echo esc_url( $content['image'] ); ?>');">
                                    <a href="<?php echo esc_url( $content['url'] ); ?>" class="post-thumbnail-link"></a>
                                </div><!-- .featured-image-->

                                <div class="entry-container">
                                    <div class="author-image">
                                        <?php echo wp_kses_post( $content['author_image'] ); ?>
                                    </div><!-- .author-image -->

                                    <header class="entry-header">
                                        <h2 class="entry-title"><a href="<?php echo esc_url( $content['author_url'] ); ?>"><?php echo esc_html( $content['author'] ); ?></a></h2>
                                    </header>

                                    <p class="no-of-stories"><span class="count"><?php echo absint( $content['author_count'] ); ?></span> <?php esc_html_e( 'Stories', 'magazinews-pro' ); ?></p>
                                </div><!-- .entry-container -->
                            </div><!-- .featured-collection-item -->
                        </article>
                    <?php endforeach; ?>
                </div><!-- .section-content-wrapper -->

                <?php if ( ! empty( $options['author_collection_btn_title'] ) && ! empty( $options['author_collection_btn_url'] ) ) : ?>
                    <div class="mobile-view view-all">
                        <a href="<?php echo esc_url( $options['author_collection_btn_url'] ); ?>" class="more-link">
                            <?php 
                                echo magazinews_pro_get_svg( array( 'icon' => 'angle-right' ) );
                                echo esc_html( $options['author_collection_btn_title'] ); 
                            ?>
                        </a>
                    </div><!-- .view-all -->
                <?php endif; ?>
            </div><!-- .wrapper -->
        </div><!-- #featured-collection -->
        
    <?php }
endif;