<?php
/**
 * Editor Choice section
 *
 * This is the template for the content of editor choice section
 *
 * @package Theme Palace
 * @subpackage Magazinews Pro
 * @since Magazinews Pro 1.0.0
 */
if ( ! function_exists( 'magazinews_pro_add_editor_choice_section' ) ) :
    /**
    * Add editor choice section
    *
    *@since Magazinews Pro 1.0.0
    */
    function magazinews_pro_add_editor_choice_section() {
    	$options = magazinews_pro_get_theme_options();
        // Check if editor choice is enabled on frontpage
        $editor_choice_enable = apply_filters( 'magazinews_pro_section_status', true, 'editor_choice_section_enable' );

        if ( true !== $editor_choice_enable ) {
            return false;
        }
        // Get editor choice section details
        $section_details = array();
        $section_details = apply_filters( 'magazinews_pro_filter_editor_choice_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render editor choice section now.
        magazinews_pro_render_editor_choice_section( $section_details );
    }
endif;

if ( ! function_exists( 'magazinews_pro_get_editor_choice_section_details' ) ) :
    /**
    * editor choice section details.
    *
    * @since Magazinews Pro 1.0.0
    * @param array $input editor choice section details.
    */
    function magazinews_pro_get_editor_choice_section_details( $input ) {
        $options = magazinews_pro_get_theme_options();

            $cats = ! empty( $options['editor_choice_content_category'] ) ? $options['editor_choice_content_category'] : array();
            $content = array();
            $i = 0;
            foreach ( $cats as $cat_id ) :
                $content[$i] = array();
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => 6,
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    


                // Run The Loop.
                $query = new WP_Query( $args );
                if ( $query->have_posts() ) : 
                    while ( $query->have_posts() ) : $query->the_post();
                        $page_post[$i]['id']        = get_the_id();
                        $page_post[$i]['title']     = get_the_title();
                        $page_post[$i]['url']       = get_the_permalink();
                        $page_post[$i]['excerpt']   = magazinews_pro_trim_content( 25 );
                        $page_post[$i]['image']  	= has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : '';

                        // Push to the main array.
                        array_push( $content[$i], $page_post[$i] );
                    endwhile;
                endif;
                wp_reset_postdata();
                $i++;
            endforeach;

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// editor choice section content details.
add_filter( 'magazinews_pro_filter_editor_choice_section_details', 'magazinews_pro_get_editor_choice_section_details' );


if ( ! function_exists( 'magazinews_pro_render_editor_choice_section' ) ) :
  /**
   * Start editor choice section
   *
   * @return string editor choice content
   * @since Magazinews Pro 1.0.0
   *
   */
   function magazinews_pro_render_editor_choice_section( $content_details = array() ) {
        $options = magazinews_pro_get_theme_options();
        $cats = ! empty( $options['editor_choice_content_category'] ) ? $options['editor_choice_content_category'] : array();
        $readmore = ! empty( $options['editor_choice_readmore'] ) ? $options['editor_choice_readmore'] : esc_html__( 'Read More', 'magazinews-pro' );
        $ads_image = ! empty( $options['editor_choice_ads'] ) ? $options['editor_choice_ads'] : '';
        $ads_alt = ! empty( $options['editor_choice_ads_alt'] ) ? $options['editor_choice_ads_alt'] : '';
        $ads_url = ! empty( $options['editor_choice_ads_url'] ) ? $options['editor_choice_ads_url'] : '';

        if ( empty( $content_details ) ) {
            return;
        } ?>

         <div id="editors-choice" class="relative page-section">
            <div class="wrapper">
                <div class="section-header-wrapper">
                    <?php if ( ! empty( $options['editor_choice_title'] ) ) : ?>
                        <div class="section-header">
                            <h2 class="section-title"><?php echo esc_html( $options['editor_choice_title'] ); ?></h2>
                        </div><!-- .section-header -->
                    <?php endif; ?>

                    <ul id="ajax-filter" class="tabs">
                        <?php $i = 1; 
                        foreach ( $cats as $cat ) : ?>
                            <li data-tab="<?php echo 'editors-choice-tab-' . absint( $cat ); ?>" data-url="<?php echo esc_url( get_category_link( $cat ) ) ?>" data-name="<?php echo esc_attr( get_cat_name( $cat ) ) ?>" <?php if ( $i == 1 ) { echo 'class="active"'; } ?>><a href="#"><?php echo esc_html( get_cat_name( $cat ) ); ?></a></li>
                        <?php $i++; endforeach; ?>
                    </ul><!-- #ajax-filter -->

                    <?php if ( ! empty( $cats ) ) : ?>
                        <div class="view-all">
                            <a href="<?php echo esc_url( get_category_link( $cats[0] ) ); ?>" class="more-link">
                                <?php 
                                    echo magazinews_pro_get_svg( array( 'icon' => 'angle-right' ) );
                                    printf( '%1$s <span>%2$s</span>', esc_html__( 'Show All ', 'magazinews-pro' ), esc_html( get_cat_name( $cats[0] ) ) );
                                ?>
                            </a>
                        </div><!-- .view-all -->
                    <?php endif; ?>
                </div><!-- .section-header-wrapper -->

                <ul id="ajax-filter" class="mobile-view tabs">
                    <?php $i = 1; 
                    foreach ( $cats as $cat ) : ?>
                        <li data-tab="<?php echo 'editors-choice-tab-' . absint( $cat ); ?>" data-url="<?php echo esc_url( get_category_link( $cat ) ) ?>" data-name="<?php echo esc_attr( get_cat_name( $cat ) ) ?>" <?php if ( $i == 1 ) { echo 'class="active"'; } ?>><a href="#"><?php echo esc_html( get_cat_name( $cat ) ); ?></a></li>
                    <?php $i++; endforeach; ?>
                </ul><!-- #ajax-filter -->

                <?php $i = 0;
                foreach ( $content_details as $content_detail ) : ?>
                    <div id="<?php echo 'editors-choice-tab-' . absint( $cats[$i] ); ?>" class="section-content-wrapper tab-content clear col-4 <?php echo ( $i == 0 ) ? 'active' : ''; ?>">

                        <?php foreach ( $content_detail as $content ) : ?>
                            <article class="has-post-thumbnail">
                                <div class="editor-post-wrapper">
                                   <?php if ( ! empty( $content['image'] ) ) : ?>
                                        <div class="featured-image" style="background-image:url('<?php echo esc_url( $content['image'] ); ?>');">
                                            <a href="<?php echo esc_url( $content['url'] ); ?>" class="post-thumbnail-link"></a>
                                        </div><!-- .featured-image-->
                                    <?php endif; ?>

                                    <div class="entry-container">
                                        <span class="cat-links">
                                            <?php the_category( '', '', $content['id'] ); ?>
                                        </span><!-- .cat-links -->

                                        <header class="entry-header">
                                            <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                        </header>

                                        <div class="entry-meta">
                                            <?php  
                                                magazinews_pro_posted_on( $content['id'] );
                                                echo magazinews_pro_author( $content['id'] );
                                            ?>
                                        </div><!-- .entry-meta -->

                                        <div class="entry-content">
                                            <p><?php echo esc_html( $content['excerpt'] ); ?></p>
                                        </div><!-- .entry-content -->

                                        <div class="read-more">
                                            <a href="#" class="more-link">
                                            <?php 
                                                echo magazinews_pro_get_svg( array( 'icon' => 'angle-right' ) );
                                                echo esc_html( $readmore );
                                            ?>
                                            </a>
                                        </div><!-- .read-more -->
                                    </div><!-- .entry-container -->
                                </div><!-- .editor-post-wrapper -->
                            </article>

                        <?php endforeach; ?>
                        
                    </div><!-- .section-content-wrapper -->
                <?php $i++; endforeach; ?>

                <?php if ( ! empty( $cats ) ) : ?>
                    <div class="mobile-view view-all">
                        <a href="<?php echo esc_url( get_category_link( $cats[0] ) ); ?>" class="more-link">
                            <?php 
                                echo magazinews_pro_get_svg( array( 'icon' => 'angle-right' ) );
                                printf( '%1$s <span>%2$s</span>', esc_html__( 'Show All ', 'magazinews-pro' ), esc_html( get_cat_name( $cats[0] ) ) );
                            ?>
                        </a>
                    </div><!-- .view-all -->
                <?php endif; ?>

                <?php if ( ! empty( $ads_image ) ) : ?>
                    <div class="advertisement">
                        <a href="<?php echo esc_url( $ads_url ); ?>">
                            <img src="<?php echo esc_url( $ads_image ); ?>" alt="<?php echo esc_attr( $ads_alt ); ?>">
                        </a>
                    </div>
                <?php endif; ?>

            </div><!-- .wrapper -->
        </div><!-- #editors-choice-posts -->

    <?php }
endif;
