<?php
/**
 * Featured Story section
 *
 * This is the template for the content of featured_story section
 *
 * @package Theme Palace
 * @subpackage Magazinews Pro
 * @since Magazinews Pro 1.0.0
 */
if ( ! function_exists( 'magazinews_pro_add_featured_story_section' ) ) :
    /**
    * Add featured_story section
    *
    *@since Magazinews Pro 1.0.0
    */
    function magazinews_pro_add_featured_story_section() {
    	$options = magazinews_pro_get_theme_options();
        // Check if featured_story is enabled on frontpage
        $featured_story_enable = apply_filters( 'magazinews_pro_section_status', true, 'featured_story_section_enable' );

        if ( true !== $featured_story_enable ) {
            return false;
        }
        // Get featured_story section details
        $section_details = array();
        $section_details = apply_filters( 'magazinews_pro_filter_featured_story_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render featured_story section now.
        magazinews_pro_render_featured_story_section( $section_details );
    }
endif;

if ( ! function_exists( 'magazinews_pro_get_featured_story_section_details' ) ) :
    /**
    * featured_story section details.
    *
    * @since Magazinews Pro 1.0.0
    * @param array $input featured_story section details.
    */
    function magazinews_pro_get_featured_story_section_details( $input ) {
        $options = magazinews_pro_get_theme_options();

        // Content type.
        $featured_story_content_type  = $options['featured_story_content_type'];
        $featured_story_count = ! empty( $options['featured_story_count'] ) ? $options['featured_story_count'] : 3;
        
        $content = array();
        switch ( $featured_story_content_type ) {
        	
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $featured_story_count; $i++ ) {
                    if ( ! empty( $options['featured_story_content_page_' . $i] ) )
                        $page_ids[] = $options['featured_story_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $featured_story_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $featured_story_count; $i++ ) {
                    if ( ! empty( $options['featured_story_content_post_' . $i] ) )
                        $post_ids[] = $options['featured_story_content_post_' . $i];
                }
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $featured_story_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['featured_story_content_category'] ) ? $options['featured_story_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $featured_story_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }


            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['id']        = get_the_id();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['excerpt']   = magazinews_pro_trim_content( 25 );
                    $page_post['image']  	= has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : '';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// featured_story section content details.
add_filter( 'magazinews_pro_filter_featured_story_section_details', 'magazinews_pro_get_featured_story_section_details' );


if ( ! function_exists( 'magazinews_pro_render_featured_story_section' ) ) :
  /**
   * Start featured_story section
   *
   * @return string featured_story content
   * @since Magazinews Pro 1.0.0
   *
   */
   function magazinews_pro_render_featured_story_section( $content_details = array() ) {
        $options = magazinews_pro_get_theme_options();
        $featured_story_content_type  = $options['featured_story_content_type'];
        $readmore = ! empty( $options['featured_story_readmore'] ) ? $options['featured_story_readmore'] : esc_html__( 'Read More', 'magazinews-pro' );
        $ads_image = ! empty( $options['featured_story_ads'] ) ? $options['featured_story_ads'] : '';
        $ads_alt = ! empty( $options['featured_story_ads_alt'] ) ? $options['featured_story_ads_alt'] : '';
        $ads_url = ! empty( $options['featured_story_ads_url'] ) ? $options['featured_story_ads_url'] : '';

        if ( empty( $content_details ) ) {
            return;
        } ?>

        <div id="featured-story" class="relative page-section">
            <div class="wrapper">
                <div class="recent-post-slider" data-slick='{"slidesToShow": 1, "slidesToScroll": 1, "infinite": true, "speed": 1500, "dots": true, "arrows":true, "autoplay": true, "draggable": true, "fade": true }'>
                    <?php foreach ( $content_details as $content ) : ?>
                        <article class="has-post-thumbnail">
                            <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                            </div><!-- .featured-image -->

                            <div class="entry-container">
                                <?php if ( $featured_story_content_type !== 'page' ) : ?>
                                    <span class="cat-links">
                                        <?php the_category( '', '', $content['id'] ); ?>
                                    </span><!-- .cat-links -->
                                <?php endif; ?>

                                <div class="left-side-content">
                                    <header class="entry-header">
                                        <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                    </header>

                                    <div class="entry-meta">
                                        <?php  
                                            magazinews_pro_posted_on( $content['id'] );
                                            echo magazinews_pro_author( $content['id'] );
                                        ?>
                                    </div><!-- .entry-meta -->
                                </div><!-- .left-side-content -->

                                <div class="right-side-content">
                                    <div class="entry-content">
                                        <p><?php echo esc_html( $content['excerpt'] ); ?></p>
                                    </div><!-- .entry-content -->

                                    <div class="read-more">
                                        <a href="<?php echo esc_url( $content['url'] ); ?>" class="more-link">
                                            <?php 
                                                echo magazinews_pro_get_svg( array( 'icon' => 'angle-right' ) );
                                                echo esc_html( $readmore ); 
                                            ?>
                                        </a>
                                    </div><!-- .read-more -->
                                </div><!-- .right-side-content -->
                            </div><!-- .entry-container -->
                        </article>
                    <?php endforeach; ?>
                </div><!-- .recent-post-slider -->

                <?php if ( ! empty( $ads_image ) ) : ?>
                    <div class="advertisement">
                        <a href="<?php echo esc_url( $ads_url ); ?>">
                            <img src="<?php echo esc_url( $ads_image ); ?>" alt="<?php echo esc_attr( $ads_alt ); ?>">
                        </a>
                    </div>
                <?php endif; ?>
                
            </div><!-- .wrapper -->
        </div><!-- #featured-story -->
        
    <?php }
endif;