<?php
/**
 * Gallery section
 *
 * This is the template for the content of gallery section
 *
 * @package Theme Palace
 * @subpackage Magazinews Pro
 * @since Magazinews Pro 1.0.0
 */
if ( ! function_exists( 'magazinews_pro_add_gallery_section' ) ) :
    /**
    * Add gallery section
    *
    *@since Magazinews Pro 1.0.0
    */
    function magazinews_pro_add_gallery_section() {
    	$options = magazinews_pro_get_theme_options();
        // Check if gallery is enabled on frontpage
        $gallery_enable = apply_filters( 'magazinews_pro_section_status', true, 'gallery_section_enable' );

        if ( true !== $gallery_enable ) {
            return false;
        }
        // Get gallery section details
        $section_details = array();
        $section_details = apply_filters( 'magazinews_pro_filter_gallery_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render gallery section now.
        magazinews_pro_render_gallery_section( $section_details );
    }
endif;

if ( ! function_exists( 'magazinews_pro_get_gallery_section_details' ) ) :
    /**
    * gallery section details.
    *
    * @since Magazinews Pro 1.0.0
    * @param array $input gallery section details.
    */
    function magazinews_pro_get_gallery_section_details( $input ) {
        $options = magazinews_pro_get_theme_options();

            $cats = ! empty( $options['gallery_content_category'] ) ? $options['gallery_content_category'] : array();
            $content = array();
            $i = 0;

            if ( ! empty( $cats ) ) :
                wp_register_script( 'magazinews-pro-gallery-localize', get_template_directory_uri() . '/assets/js/gallery-localize' . magazinews_pro_min() . '.js', array( 'jquery','magazinews-pro-custom' ), '20151215', true );
                $magazinews_pro_gallery_category = array(
                    'cat'          => $cats[0],
                );
                wp_localize_script( 'magazinews-pro-gallery-localize', 'magazinews_pro_gallery_category', $magazinews_pro_gallery_category );
                wp_enqueue_script( 'magazinews-pro-gallery-localize' );
            endif;

            foreach ( $cats as $cat_id ) :
                $content[$i] = array();
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => 7,
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    


                // Run The Loop.
                $query = new WP_Query( $args );
                if ( $query->have_posts() ) : 
                    while ( $query->have_posts() ) : $query->the_post();
                        $page_post[$i]['id']        = get_the_id();
                        $page_post[$i]['title']     = get_the_title();
                        $page_post[$i]['url']       = get_the_permalink();
                        $page_post[$i]['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : '';

                        // Push to the main array.
                        array_push( $content[$i], $page_post[$i] );
                    endwhile;
                endif;
                wp_reset_postdata();
                $i++;
            endforeach;

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// gallery section content details.
add_filter( 'magazinews_pro_filter_gallery_section_details', 'magazinews_pro_get_gallery_section_details' );


if ( ! function_exists( 'magazinews_pro_render_gallery_section' ) ) :
  /**
   * Start gallery section
   *
   * @return string gallery content
   * @since Magazinews Pro 1.0.0
   *
   */
   function magazinews_pro_render_gallery_section( $content_details = array() ) {
        $options = magazinews_pro_get_theme_options();
        $cats = ! empty( $options['gallery_content_category'] ) ? $options['gallery_content_category'] : array();
        $ads_image = ! empty( $options['gallery_ads'] ) ? $options['gallery_ads'] : '';
        $ads_alt = ! empty( $options['gallery_ads_alt'] ) ? $options['gallery_ads_alt'] : '';
        $ads_url = ! empty( $options['gallery_ads_url'] ) ? $options['gallery_ads_url'] : '';

        if ( empty( $content_details ) ) {
            return;
        } ?>

        <div id="gallery-posts" class="relative page-section">
            <div class="wrapper">
                <div class="gallery-post-wrapper clear">
                    <div class="remaining-gallery-posts">
                        <div class="section-header-wrapper">
                            <?php if ( ! empty( $options['gallery_title'] ) ) : ?>
                                <div class="section-header">
                                    <h2 class="section-title"><?php echo esc_html( $options['gallery_title'] ); ?></h2>
                                </div><!-- .section-header -->
                            <?php endif; 

                            if ( ! empty( $cats ) ) : ?>
                                <div class="view-all">
                                    <a href="<?php echo esc_url( get_category_link( $cats[0] ) ); ?>" class="more-link">
                                        <?php 
                                            echo magazinews_pro_get_svg( array( 'icon' => 'angle-right' ) );
                                            printf( '%1$s <span>%2$s</span>', esc_html__( 'Show All ', 'magazinews-pro' ), esc_html( get_cat_name( $cats[0] ) ) );
                                        ?>
                                    </a>
                                </div><!-- .view-all -->
                            <?php endif; ?>
                        </div><!-- .section-header-wrapper -->

                        <ul id="ajax-filter" class="tabs">
                            <?php $i = 1;
                            foreach ( $cats as $cat ) : ?>
                                <li data-tab="<?php echo 'gallery-tab-' . absint( $cat ); ?>" data-id="<?php echo absint( $cat ) ?>" data-url="<?php echo esc_url( get_category_link( $cat ) ) ?>" data-name="<?php echo esc_attr( get_cat_name( $cat ) ) ?>" <?php if ( $i == 1 ) { echo 'class="active"'; } ?>><a href="#"><?php echo esc_html( get_cat_name( $cat ) ); ?></a></li>
                            <?php $i++; endforeach; ?>
                        </ul><!-- #ajax-filter -->

                        <?php $i = 0;
                        foreach ( $content_details as $content_detail ) : ?>
                            <div id="<?php echo 'gallery-tab-' . absint( $cats[$i] ); ?>" class="section-content-wrapper tab-content clear <?php echo ( $i == 0 ) ? 'active' : ''; ?>">
                                <?php foreach ( $content_detail as $content ) : ?>
                                    <article>
                                        <div class="gallery-post-item" style="background-image:url('<?php echo esc_url( $content['image'] ); ?>')">
                                            <div class="entry-container">
                                                <header class="entry-header">
                                                    <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                                </header>

                                                <div class="entry-meta">
                                                    <?php
                                                        magazinews_pro_posted_on( $content['id'] );
                                                        echo magazinews_pro_author( $content['id'] );
                                                    ?>
                                                </div><!-- .entry-meta -->
                                            </div><!-- .entry-container -->
                                        </div><!-- .gallery-post-item -->
                                    </article>
                                <?php endforeach; ?>
                            </div><!-- .section-content-wrapper -->
                        <?php $i++; endforeach; ?>
                    </div><!-- .remaining-gallery-posts -->

                    <div class="first-gallery-post">
                    </div><!-- .first-gallery-post -->
                </div><!-- .gallery-post-wrapper -->

                <?php if ( ! empty( $cats ) ) : ?>
                    <div class="mobile-view view-all">
                        <a href="<?php echo esc_url( get_category_link( $cats[0] ) ); ?>" class="more-link">
                            <?php 
                                echo magazinews_pro_get_svg( array( 'icon' => 'angle-right' ) );
                                printf( '%1$s <span>%2$s</span>', esc_html__( 'Show All ', 'magazinews-pro' ), esc_html( get_cat_name( $cats[0] ) ) );
                            ?>
                        </a>
                    </div><!-- .view-all -->
                <?php endif; ?>

                <?php if ( ! empty( $ads_image ) ) : ?>
                    <div class="advertisement">
                        <a href="<?php echo esc_url( $ads_url ); ?>">
                            <img src="<?php echo esc_url( $ads_image ); ?>" alt="<?php echo esc_attr( $ads_alt ); ?>">
                        </a>
                    </div>
                <?php endif; ?>

            </div><!-- .wrapper -->
        </div><!-- #gallery-posts -->

    <?php }
endif;